@@ -22,21 +22,20 @@ from urllib import unquote
 from xml.sax import saxutils
 
 from eventlet import Timeout
-from webob import Request, Response
-from webob.exc import HTTPAccepted, HTTPBadRequest, \
-    HTTPCreated, HTTPForbidden, HTTPInternalServerError, \
-    HTTPMethodNotAllowed, HTTPNoContent, HTTPNotFound, \
-    HTTPPreconditionFailed, HTTPConflict
 
 import swift.common.db
 from swift.common.db import AccountBroker
 from swift.common.utils import get_logger, get_param, hash_path, public, \
-    normalize_timestamp, split_path, storage_directory, TRUE_VALUES, \
+    normalize_timestamp, split_path, storage_directory, config_true_value, \
     validate_device_partition, json
 from swift.common.constraints import ACCOUNT_LISTING_LIMIT, \
     check_mount, check_float, check_utf8, FORMAT2CONTENT_TYPE
 from swift.common.db_replicator import ReplicatorRpc
-from swift.common.http import HTTPInsufficientStorage
+from swift.common.swob import HTTPAccepted, HTTPBadRequest, \
+    HTTPCreated, HTTPForbidden, HTTPInternalServerError, \
+    HTTPMethodNotAllowed, HTTPNoContent, HTTPNotFound, \
+    HTTPPreconditionFailed, HTTPConflict, Request, Response, \
+    HTTPInsufficientStorage
 
 
 DATADIR = 'accounts'
@@ -48,14 +47,14 @@ class AccountController(object):
     def __init__(self, conf):
         self.logger = get_logger(conf, log_route='account-server')
         self.root = conf.get('devices', '/srv/node')
-        self.mount_check = conf.get('mount_check', 'true').lower() in \
-                              ('true', 't', '1', 'on', 'yes', 'y')
+        self.mount_check = config_true_value(conf.get('mount_check', 'true'))
         self.replicator_rpc = ReplicatorRpc(self.root, DATADIR, AccountBroker,
-            self.mount_check, logger=self.logger)
+                                            self.mount_check,
+                                            logger=self.logger)
         self.auto_create_account_prefix = \
             conf.get('auto_create_account_prefix') or '.'
         swift.common.db.DB_PREALLOCATION = \
-            conf.get('db_preallocation', 'f').lower() in TRUE_VALUES
+            config_true_value(conf.get('db_preallocation', 'f'))
 
     def _get_account_broker(self, drive, part, account):
         hsh = hash_path(account)
@@ -73,15 +72,15 @@ class AccountController(object):
         except ValueError, err:
             self.logger.increment('DELETE.errors')
             return HTTPBadRequest(body=str(err), content_type='text/plain',
-                                                    request=req)
+                                  request=req)
         if self.mount_check and not check_mount(self.root, drive):
             self.logger.increment('DELETE.errors')
             return HTTPInsufficientStorage(drive=drive, request=req)
         if 'x-timestamp' not in req.headers or \
-                    not check_float(req.headers['x-timestamp']):
+                not check_float(req.headers['x-timestamp']):
             self.logger.increment('DELETE.errors')
             return HTTPBadRequest(body='Missing timestamp', request=req,
-                        content_type='text/plain')
+                                  content_type='text/plain')
         broker = self._get_account_broker(drive, part, account)
         if broker.is_deleted():
             self.logger.timing_since('DELETE.timing', start_time)
@@ -118,9 +117,9 @@ class AccountController(object):
                 self.logger.timing_since('PUT.timing', start_time)
                 return HTTPNotFound(request=req)
             broker.put_container(container, req.headers['x-put-timestamp'],
-                req.headers['x-delete-timestamp'],
-                req.headers['x-object-count'],
-                req.headers['x-bytes-used'])
+                                 req.headers['x-delete-timestamp'],
+                                 req.headers['x-object-count'],
+                                 req.headers['x-bytes-used'])
             self.logger.timing_since('PUT.timing', start_time)
             if req.headers['x-delete-timestamp'] > \
                     req.headers['x-put-timestamp']:
@@ -143,8 +142,8 @@ class AccountController(object):
                     return HTTPConflict(request=req)
             metadata = {}
             metadata.update((key, (value, timestamp))
-                for key, value in req.headers.iteritems()
-                if key.lower().startswith('x-account-meta-'))
+                            for key, value in req.headers.iteritems()
+                            if key.lower().startswith('x-account-meta-'))
             if metadata:
                 broker.update_metadata(metadata)
             self.logger.timing_since('PUT.timing', start_time)
@@ -170,7 +169,7 @@ class AccountController(object):
         except ValueError, err:
             self.logger.increment('HEAD.errors')
             return HTTPBadRequest(body=str(err), content_type='text/plain',
-                                                    request=req)
+                                  request=req)
         if self.mount_check and not check_mount(self.root, drive):
             self.logger.increment('HEAD.errors')
             return HTTPInsufficientStorage(drive=drive, request=req)
@@ -193,8 +192,8 @@ class AccountController(object):
             if container_ts is not None:
                 headers['X-Container-Timestamp'] = container_ts
         headers.update((key, value)
-            for key, (value, timestamp) in broker.metadata.iteritems()
-            if value != '')
+                       for key, (value, timestamp) in
+                       broker.metadata.iteritems() if value != '')
         self.logger.timing_since('HEAD.timing', start_time)
         return HTTPNoContent(request=req, headers=headers)
 
@@ -208,7 +207,7 @@ class AccountController(object):
         except ValueError, err:
             self.logger.increment('GET.errors')
             return HTTPBadRequest(body=str(err), content_type='text/plain',
-                                                    request=req)
+                                  request=req)
         if self.mount_check and not check_mount(self.root, drive):
             self.logger.increment('GET.errors')
             return HTTPInsufficientStorage(drive=drive, request=req)
@@ -226,8 +225,8 @@ class AccountController(object):
             'X-Timestamp': info['created_at'],
             'X-PUT-Timestamp': info['put_timestamp']}
         resp_headers.update((key, value)
-            for key, (value, timestamp) in broker.metadata.iteritems()
-            if value != '')
+                            for key, (value, timestamp) in
+                            broker.metadata.iteritems() if value != '')
         try:
             prefix = get_param(req, 'prefix')
             delimiter = get_param(req, 'delimiter')
@@ -242,7 +241,8 @@ class AccountController(object):
                 if limit > ACCOUNT_LISTING_LIMIT:
                     self.logger.increment('GET.errors')
                     return HTTPPreconditionFailed(request=req,
-                        body='Maximum limit is %d' % ACCOUNT_LISTING_LIMIT)
+                                                  body='Maximum limit is %d' %
+                                                  ACCOUNT_LISTING_LIMIT)
             marker = get_param(req, 'marker', '')
             end_marker = get_param(req, 'end_marker')
             query_format = get_param(req, 'format')
@@ -255,9 +255,9 @@ class AccountController(object):
                                                  FORMAT2CONTENT_TYPE['plain'])
         try:
             out_content_type = req.accept.best_match(
-                                    ['text/plain', 'application/json',
-                                     'application/xml', 'text/xml'],
-                                    default_match='text/plain')
+                ['text/plain', 'application/json', 'application/xml',
+                 'text/xml'],
+                default_match='text/plain')
         except AssertionError, err:
             self.logger.increment('GET.errors')
             return HTTPBadRequest(body='bad accept header: %s' % req.accept,
@@ -312,7 +312,7 @@ class AccountController(object):
         except ValueError, err:
             self.logger.increment('REPLICATE.errors')
             return HTTPBadRequest(body=str(err), content_type='text/plain',
-                                                    request=req)
+                                  request=req)
         if self.mount_check and not check_mount(self.root, drive):
             self.logger.increment('REPLICATE.errors')
             return HTTPInsufficientStorage(drive=drive, request=req)
@@ -341,7 +341,8 @@ class AccountController(object):
                 not check_float(req.headers['x-timestamp']):
             self.logger.increment('POST.errors')
             return HTTPBadRequest(body='Missing or bad timestamp',
-                request=req, content_type='text/plain')
+                                  request=req,
+                                  content_type='text/plain')
         if self.mount_check and not check_mount(self.root, drive):
             self.logger.increment('POST.errors')
             return HTTPInsufficientStorage(drive=drive, request=req)
@@ -352,8 +353,8 @@ class AccountController(object):
         timestamp = normalize_timestamp(req.headers['x-timestamp'])
         metadata = {}
         metadata.update((key, (value, timestamp))
-            for key, value in req.headers.iteritems()
-            if key.lower().startswith('x-account-meta-'))
+                        for key, value in req.headers.iteritems()
+                        if key.lower().startswith('x-account-meta-'))
         if metadata:
             broker.update_metadata(metadata)
         self.logger.timing_since('POST.timing', start_time)
@@ -377,7 +378,8 @@ class AccountController(object):
                     res = method(req)
             except (Exception, Timeout):
                 self.logger.exception(_('ERROR __call__ error with %(method)s'
-                    ' %(path)s '), {'method': req.method, 'path': req.path})
+                                        ' %(path)s '),
+                                      {'method': req.method, 'path': req.path})
                 res = HTTPInternalServerError(body=traceback.format_exc())
         trans_time = '%.4f' % (time.time() - start_time)
         additional_info = ''
