@@ -14,29 +14,51 @@
 # limitations under the License.
 
 import os
+from ConfigParser import ConfigParser, NoSectionError, NoOptionError, \
+    RawConfigParser
 
-from webob.exc import HTTPBadRequest, HTTPLengthRequired, \
+from swift.common.swob import HTTPBadRequest, HTTPLengthRequired, \
     HTTPRequestEntityTooLarge
 
+constraints_conf = ConfigParser()
+constraints_conf.read('/etc/swift/swift.conf')
+
+
+def constraints_conf_int(name, default):
+    try:
+        return int(constraints_conf.get('swift-constraints', name))
+    except (NoSectionError, NoOptionError):
+        return default
+
 
 #: Max file size allowed for objects
-MAX_FILE_SIZE = 5 * 1024 * 1024 * 1024 + 2
+MAX_FILE_SIZE = constraints_conf_int('max_file_size',
+                                     5368709122)  # 5 * 1024 * 1024 * 1024 + 2
 #: Max length of the name of a key for metadata
-MAX_META_NAME_LENGTH = 128
+MAX_META_NAME_LENGTH = constraints_conf_int('max_meta_name_length', 128)
 #: Max length of the value of a key for metadata
-MAX_META_VALUE_LENGTH = 256
+MAX_META_VALUE_LENGTH = constraints_conf_int('max_meta_value_length', 256)
 #: Max number of metadata items
-MAX_META_COUNT = 90
+MAX_META_COUNT = constraints_conf_int('max_meta_count', 90)
 #: Max overall size of metadata
-MAX_META_OVERALL_SIZE = 4096
+MAX_META_OVERALL_SIZE = constraints_conf_int('max_meta_overall_size', 4096)
 #: Max object name length
-MAX_OBJECT_NAME_LENGTH = 1024
+MAX_OBJECT_NAME_LENGTH = constraints_conf_int('max_object_name_length', 1024)
 #: Max object list length of a get request for a container
-CONTAINER_LISTING_LIMIT = 10000
+CONTAINER_LISTING_LIMIT = constraints_conf_int('container_listing_limit',
+                                               10000)
 #: Max container list length of a get request for an account
-ACCOUNT_LISTING_LIMIT = 10000
-MAX_ACCOUNT_NAME_LENGTH = 256
-MAX_CONTAINER_NAME_LENGTH = 256
+ACCOUNT_LISTING_LIMIT = constraints_conf_int('account_listing_limit', 10000)
+#: Max account name length
+MAX_ACCOUNT_NAME_LENGTH = constraints_conf_int('max_account_name_length', 256)
+#: Max container name length
+MAX_CONTAINER_NAME_LENGTH = constraints_conf_int('max_container_name_length',
+                                                 256)
+
+
+#: Query string format= values to their corresponding content-type values
+FORMAT2CONTENT_TYPE = {'plain': 'text/plain', 'json': 'application/json',
+                       'xml': 'application/xml'}
 
 
 def check_metadata(req, target_type):
@@ -57,28 +79,26 @@ def check_metadata(req, target_type):
         key = key[len(prefix):]
         if not key:
             return HTTPBadRequest(body='Metadata name cannot be empty',
-                    request=req, content_type='text/plain')
+                                  request=req, content_type='text/plain')
         meta_count += 1
         meta_size += len(key) + len(value)
         if len(key) > MAX_META_NAME_LENGTH:
             return HTTPBadRequest(
-                    body='Metadata name too long; max %d'
-                        % MAX_META_NAME_LENGTH,
-                    request=req, content_type='text/plain')
+                body='Metadata name too long; max %d' % MAX_META_NAME_LENGTH,
+                request=req, content_type='text/plain')
         elif len(value) > MAX_META_VALUE_LENGTH:
             return HTTPBadRequest(
-                    body='Metadata value too long; max %d'
-                        % MAX_META_VALUE_LENGTH,
-                    request=req, content_type='text/plain')
+                body='Metadata value too long; max %d' % MAX_META_VALUE_LENGTH,
+                request=req, content_type='text/plain')
         elif meta_count > MAX_META_COUNT:
             return HTTPBadRequest(
-                    body='Too many metadata items; max %d' % MAX_META_COUNT,
-                    request=req, content_type='text/plain')
+                body='Too many metadata items; max %d' % MAX_META_COUNT,
+                request=req, content_type='text/plain')
         elif meta_size > MAX_META_OVERALL_SIZE:
             return HTTPBadRequest(
-                    body='Total metadata too large; max %d'
-                        % MAX_META_OVERALL_SIZE,
-                    request=req, content_type='text/plain')
+                body='Total metadata too large; max %d'
+                % MAX_META_OVERALL_SIZE,
+                request=req, content_type='text/plain')
     return None
 
 
@@ -96,7 +116,8 @@ def check_object_creation(req, object_name):
     """
     if req.content_length and req.content_length > MAX_FILE_SIZE:
         return HTTPRequestEntityTooLarge(body='Your request is too large.',
-                request=req, content_type='text/plain')
+                                         request=req,
+                                         content_type='text/plain')
     if req.content_length is None and \
             req.headers.get('transfer-encoding') != 'chunked':
         return HTTPLengthRequired(request=req)
@@ -105,14 +126,14 @@ def check_object_creation(req, object_name):
                               request=req, content_type='text/plain')
     if len(object_name) > MAX_OBJECT_NAME_LENGTH:
         return HTTPBadRequest(body='Object name length of %d longer than %d' %
-                (len(object_name), MAX_OBJECT_NAME_LENGTH), request=req,
-                content_type='text/plain')
+                              (len(object_name), MAX_OBJECT_NAME_LENGTH),
+                              request=req, content_type='text/plain')
     if 'Content-Type' not in req.headers:
         return HTTPBadRequest(request=req, content_type='text/plain',
-                    body='No content type')
+                              body='No content type')
     if not check_utf8(req.headers['Content-Type']):
         return HTTPBadRequest(request=req, body='Invalid Content-Type',
-                    content_type='text/plain')
+                              content_type='text/plain')
     if 'x-object-manifest' in req.headers:
         value = req.headers['x-object-manifest']
         container = prefix = None
@@ -122,7 +143,8 @@ def check_object_creation(req, object_name):
             pass
         if not container or not prefix or '?' in value or '&' in value or \
                 prefix[0] == '/':
-            return HTTPBadRequest(request=req,
+            return HTTPBadRequest(
+                request=req,
                 body='X-Object-Manifest must in the format container/prefix')
     return check_metadata(req, 'object')
 
