@@ -76,14 +76,15 @@ def run_daemon(klass, conf_file, section_name='', once=False, **kwargs):
 
     # once on command line (i.e. daemonize=false) will over-ride config
     once = once or \
-            conf.get('daemonize', 'true').lower() not in utils.TRUE_VALUES
+        conf.get('daemonize', 'true').lower() not in utils.TRUE_VALUES
 
     # pre-configure logger
     if 'logger' in kwargs:
         logger = kwargs.pop('logger')
     else:
         logger = utils.get_logger(conf, conf.get('log_name', section_name),
-           log_to_console=kwargs.pop('verbose', False), log_route=section_name)
+                                  log_to_console=kwargs.pop('verbose', False),
+                                  log_route=section_name)
 
     # disable fallocate if desired
     if conf.get('disable_fallocate', 'no').lower() in utils.TRUE_VALUES:
