@@ -19,12 +19,11 @@ from paste.deploy import loadapp
 import struct
 from sys import exc_info
 from urllib import quote
-from webob import Request
 import zlib
 from zlib import compressobj
 
-
 from swift.common.http import HTTP_NOT_FOUND
+from swift.common.swob import Request
 
 
 class UnexpectedResponse(Exception):
@@ -54,8 +53,9 @@ class CompressingFileReader(object):
 
     def __init__(self, file_obj, compresslevel=9):
         self._f = file_obj
-        self._compressor = compressobj(compresslevel, zlib.DEFLATED,
-            -zlib.MAX_WBITS, zlib.DEF_MEM_LEVEL, 0)
+        self._compressor = compressobj(
+            compresslevel, zlib.DEFLATED, -zlib.MAX_WBITS, zlib.DEF_MEM_LEVEL,
+            0)
         self.done = False
         self.first = True
         self.crc32 = 0
@@ -119,8 +119,8 @@ class InternalClient(object):
         self.user_agent = user_agent
         self.request_tries = request_tries
 
-    def make_request(self, method, path, headers, acceptable_statuses,
-            body_file=None):
+    def make_request(
+            self, method, path, headers, acceptable_statuses, body_file=None):
         """
         Makes a request to Swift with retries.
 
@@ -143,8 +143,8 @@ class InternalClient(object):
         headers['user-agent'] = self.user_agent
         resp = exc_type = exc_value = exc_traceback = None
         for attempt in xrange(self.request_tries):
-            req = Request.blank(path, environ={'REQUEST_METHOD': method},
-                headers=headers)
+            req = Request.blank(
+                path, environ={'REQUEST_METHOD': method}, headers=headers)
             if body_file is not None:
                 if hasattr(body_file, 'seek'):
                     body_file.seek(0)
@@ -158,14 +158,14 @@ class InternalClient(object):
                 exc_type, exc_value, exc_traceback = exc_info()
             sleep(2 ** (attempt + 1))
         if resp:
-            raise UnexpectedResponse(_('Unexpected response: %s' %
-                (resp.status,)), resp)
+            raise UnexpectedResponse(
+                _('Unexpected response: %s' % (resp.status,)), resp)
         if exc_type:
             # To make pep8 tool happy, in place of raise t, v, tb:
             raise exc_type(*exc_value.args), None, exc_traceback
 
-    def _get_metadata(self, path, metadata_prefix='',
-            acceptable_statuses=(2,)):
+    def _get_metadata(
+            self, path, metadata_prefix='', acceptable_statuses=(2,)):
         """
         Gets metadata by doing a HEAD on a path and using the metadata_prefix
         to get values from the headers returned.
@@ -193,7 +193,8 @@ class InternalClient(object):
                 metadata[k[len(metadata_prefix):]] = v
         return metadata
 
-    def _iter_items(self, path, marker='', end_marker='',
+    def _iter_items(
+            self, path, marker='', end_marker='',
             acceptable_statuses=(2, HTTP_NOT_FOUND)):
         """
         Returns an iterator of items from a json listing.  Assumes listing has
@@ -213,9 +214,9 @@ class InternalClient(object):
         """
 
         while True:
-            resp = self.make_request('GET',
-                '%s?format=json&marker=%s&end_marker=%s' %
-                    (path, quote(marker), quote(end_marker)),
+            resp = self.make_request(
+                'GET', '%s?format=json&marker=%s&end_marker=%s' %
+                (path, quote(marker), quote(end_marker)),
                 {}, acceptable_statuses)
             if resp.status_int != 200:
                 break
@@ -226,7 +227,40 @@ class InternalClient(object):
                 yield item
             marker = data[-1]['name']
 
-    def _set_metadata(self, path, metadata, metadata_prefix='',
+    def make_path(self, account, container=None, obj=None):
+        """
+        Returns a swift path for a request quoting and utf-8 encoding the path
+        parts as need be.
+
+        :param account: swift account
+        :param container: container, defaults to None
+        :param obj: object, defaults to None
+
+        :raises ValueError: Is raised if obj is specified and container is
+                            not.
+        """
+
+        if isinstance(account, unicode):
+            account = account.encode('utf-8')
+
+        if isinstance(container, unicode):
+            container = container.encode('utf-8')
+
+        if isinstance(obj, unicode):
+            obj = obj.encode('utf-8')
+
+        path = '/v1/%s' % quote(account)
+        if container:
+            path += '/%s' % quote(container)
+
+            if obj:
+                path += '/%s' % quote(obj)
+        elif obj:
+            raise ValueError('Object specified without container')
+        return path
+
+    def _set_metadata(
+            self, path, metadata, metadata_prefix='',
             acceptable_statuses=(2,)):
         """
         Sets metadata on path using metadata_prefix to set values in headers of
@@ -256,7 +290,8 @@ class InternalClient(object):
 
     # account methods
 
-    def iter_containers(self, account, marker='', end_marker='',
+    def iter_containers(
+            self, account, marker='', end_marker='',
             acceptable_statuses=(2, HTTP_NOT_FOUND)):
         """
         Returns an iterator of containers dicts from an account.
@@ -274,11 +309,11 @@ class InternalClient(object):
                            unexpected way.
         """
 
-        path = '/v1/%s' % (quote(account),)
+        path = self.make_path(account)
         return self._iter_items(path, marker, end_marker, acceptable_statuses)
 
-    def get_account_info(self, account,
-            acceptable_statuses=(2, HTTP_NOT_FOUND)):
+    def get_account_info(
+            self, account, acceptable_statuses=(2, HTTP_NOT_FOUND)):
         """
         Returns (container_count, object_count) for an account.
 
@@ -292,13 +327,13 @@ class InternalClient(object):
                            unexpected way.
         """
 
-        path = '/v1/%s' % (quote(account),)
+        path = self.make_path(account)
         resp = self.make_request('HEAD', path, {}, acceptable_statuses)
         return (int(resp.headers.get('x-account-container-count', 0)),
-            int(resp.headers.get('x-account-object-count', 0)))
+                int(resp.headers.get('x-account-object-count', 0)))
 
-    def get_account_metadata(self, account, metadata_prefix='',
-            acceptable_statuses=(2,)):
+    def get_account_metadata(
+            self, account, metadata_prefix='', acceptable_statuses=(2,)):
         """
         Gets account metadata.
 
@@ -317,10 +352,11 @@ class InternalClient(object):
                            unexpected way.
         """
 
-        path = '/v1/%s' % (quote(account))
+        path = self.make_path(account)
         return self._get_metadata(path, metadata_prefix, acceptable_statuses)
 
-    def set_account_metadata(self, account, metadata, metadata_prefix='',
+    def set_account_metadata(
+            self, account, metadata, metadata_prefix='',
             acceptable_statuses=(2,)):
         """
         Sets account metadata.  A call to this will add to the account
@@ -342,9 +378,9 @@ class InternalClient(object):
                            unexpected way.
         """
 
-        path = '/v1/%s' % (quote(account))
-        self._set_metadata(path, metadata, metadata_prefix,
-            acceptable_statuses)
+        path = self.make_path(account)
+        self._set_metadata(
+            path, metadata, metadata_prefix, acceptable_statuses)
 
     # container methods
 
@@ -363,12 +399,12 @@ class InternalClient(object):
                            unexpected way.
         """
 
-        path = '/v1/%s/%s' % (quote(account), quote(container))
+        path = self.make_path(account, container)
         resp = self.make_request('HEAD', path, {}, (2, HTTP_NOT_FOUND))
         return resp.status_int != HTTP_NOT_FOUND
 
-    def create_container(self, account, container, headers=None,
-            acceptable_statuses=(2,)):
+    def create_container(
+            self, account, container, headers=None, acceptable_statuses=(2,)):
         """
         Creates container.
 
@@ -385,11 +421,11 @@ class InternalClient(object):
         """
 
         headers = headers or {}
-        path = '/v1/%s/%s' % (quote(account), quote(container))
+        path = self.make_path(account, container)
         self.make_request('PUT', path, headers, acceptable_statuses)
 
-    def delete_container(self, account, container,
-            acceptable_statuses=(2, HTTP_NOT_FOUND)):
+    def delete_container(
+            self, account, container, acceptable_statuses=(2, HTTP_NOT_FOUND)):
         """
         Deletes a container.
 
@@ -404,10 +440,11 @@ class InternalClient(object):
                            unexpected way.
         """
 
-        path = '/v1/%s/%s' % (quote(account), quote(container))
+        path = self.make_path(account, container)
         self.make_request('DELETE', path, {}, acceptable_statuses)
 
-    def get_container_metadata(self, account, container, metadata_prefix='',
+    def get_container_metadata(
+            self, account, container, metadata_prefix='',
             acceptable_statuses=(2,)):
         """
         Gets container metadata.
@@ -428,10 +465,11 @@ class InternalClient(object):
                            unexpected way.
         """
 
-        path = '/v1/%s/%s' % (quote(account), quote(container))
+        path = self.make_path(account, container)
         return self._get_metadata(path, metadata_prefix, acceptable_statuses)
 
-    def iter_objects(self, account, container, marker='', end_marker='',
+    def iter_objects(
+            self, account, container, marker='', end_marker='',
             acceptable_statuses=(2, HTTP_NOT_FOUND)):
         """
         Returns an iterator of object dicts from a container.
@@ -450,11 +488,12 @@ class InternalClient(object):
                            unexpected way.
         """
 
-        path = '/v1/%s/%s' % (quote(account), quote(container))
+        path = self.make_path(account, container)
         return self._iter_items(path, marker, end_marker, acceptable_statuses)
 
-    def set_container_metadata(self, account, container, metadata,
-            metadata_prefix='', acceptable_statuses=(2,)):
+    def set_container_metadata(
+            self, account, container, metadata, metadata_prefix='',
+            acceptable_statuses=(2,)):
         """
         Sets container metadata.  A call to this will add to the container
         metadata and not overwrite all of it with values in the metadata dict.
@@ -476,20 +515,21 @@ class InternalClient(object):
                            unexpected way.
         """
 
-        path = '/v1/%s/%s' % (quote(account), quote(container))
-        self._set_metadata(path, metadata, metadata_prefix,
-            acceptable_statuses)
+        path = self.make_path(account, container)
+        self._set_metadata(
+            path, metadata, metadata_prefix, acceptable_statuses)
 
     # object methods
 
-    def delete_object(self, account, container, object_name,
+    def delete_object(
+            self, account, container, obj,
             acceptable_statuses=(2, HTTP_NOT_FOUND)):
         """
         Deletes an object.
 
         :param account: The object's account.
         :param container: The object's container.
-        :param object_name: The object.
+        :param obj: The object.
         :param acceptable_statuses: List of status for valid responses,
                                     defaults to (2, HTTP_NOT_FOUND).
 
@@ -499,18 +539,18 @@ class InternalClient(object):
                            unexpected way.
         """
 
-        path = '/v1/%s/%s/%s' % (quote(account), quote(container),
-            quote(object_name))
+        path = self.make_path(account, container, obj)
         self.make_request('DELETE', path, {}, acceptable_statuses)
 
-    def get_object_metadata(self, account, container, object_name,
-            metadata_prefix='', acceptable_statuses=(2,)):
+    def get_object_metadata(
+            self, account, container, obj, metadata_prefix='',
+            acceptable_statuses=(2,)):
         """
         Gets object metadata.
 
         :param account: The object's account.
         :param container: The object's container.
-        :param object_name: The object.
+        :param obj: The object.
         :param metadata_prefix: Used to filter values from the headers
                                 returned.  Will strip that prefix from the
                                 keys in the dict returned.  Defaults to ''.
@@ -525,11 +565,11 @@ class InternalClient(object):
                            unexpected way.
         """
 
-        path = '/v1/%s/%s/%s' % (quote(account), quote(container),
-            quote(object_name))
+        path = self.make_path(account, container, obj)
         return self._get_metadata(path, metadata_prefix, acceptable_statuses)
 
-    def iter_object_lines(self, account, container, object_name, headers=None,
+    def iter_object_lines(
+            self, account, container, obj, headers=None,
             acceptable_statuses=(2,)):
         """
         Returns an iterator of object lines from an uncompressed or compressed
@@ -550,13 +590,12 @@ class InternalClient(object):
         """
 
         headers = headers or {}
-        path = '/v1/%s/%s/%s' % (quote(account), quote(container),
-            quote(object_name))
+        path = self.make_path(account, container, obj)
 
         resp = self.make_request('GET', path, headers, acceptable_statuses)
 
         last_part = ''
-        compressed = object_name.endswith('.gz')
+        compressed = obj.endswith('.gz')
         # magic in the following zlib.decompressobj argument is courtesy of
         # Python decompressing gzip chunk-by-chunk
         # http://stackoverflow.com/questions/2423866
@@ -575,7 +614,8 @@ class InternalClient(object):
         if last_part:
             yield last_part
 
-    def set_object_metadata(self, account, container, object_name, metadata,
+    def set_object_metadata(
+            self, account, container, obj, metadata,
             metadata_prefix='', acceptable_statuses=(2,)):
         """
         Sets an object's metadata.  The object's metadata will be overwritten
@@ -583,7 +623,7 @@ class InternalClient(object):
 
         :param account: The object's account.
         :param container: The object's container.
-        :param object_name: The object.
+        :param obj: The object.
         :param metadata: Dict of metadata to set.
         :param metadata_prefix: Prefix used to set metadata values in headers
                                 of requests, used to prefix keys in metadata
@@ -597,18 +637,17 @@ class InternalClient(object):
                            unexpected way.
         """
 
-        path = '/v1/%s/%s/%s' % (quote(account), quote(container),
-            quote(object_name))
-        self._set_metadata(path, metadata, metadata_prefix,
-            acceptable_statuses)
+        path = self.make_path(account, container, obj)
+        self._set_metadata(
+            path, metadata, metadata_prefix, acceptable_statuses)
 
-    def upload_object(self, fobj, account, container, object_name,
-            headers=None):
+    def upload_object(
+            self, fobj, account, container, obj, headers=None):
         """
         :param fobj: File object to read object's content from.
         :param account: The object's account.
         :param container: The object's container.
-        :param object_name: The object.
+        :param obj: The object.
         :param headers: Headers to send with request, defaults ot empty dict.
 
         :raises UnexpectedResponse: Exception raised when requests fail
@@ -619,6 +658,5 @@ class InternalClient(object):
 
         headers = dict(headers or {})
         headers['Transfer-Encoding'] = 'chunked'
-        path = '/v1/%s/%s/%s' % (quote(account), quote(container),
-            quote(object_name))
+        path = self.make_path(account, container, obj)
         self.make_request('PUT', path, headers, (2,), fobj)
