@@ -63,6 +63,7 @@ logging._levelNames[NOTICE] = 'NOTICE'
 SysLogHandler.priority_map['NOTICE'] = 'notice'
 
 # These are lazily pulled from libc elsewhere
+_sys_fsync = None
 _sys_fallocate = None
 _posix_fadvise = None
 
@@ -170,10 +171,53 @@ def fallocate(fd, size):
         # 1 means "FALLOC_FL_KEEP_SIZE", which means it pre-allocates invisibly
         ret = _sys_fallocate(fd, 1, 0, ctypes.c_uint64(size))
         err = ctypes.get_errno()
-        if ret and err not in (0, errno.ENOSYS, errno.EOPNOTSUPP):
+        if ret and err not in (0, errno.ENOSYS, errno.EOPNOTSUPP,
+                               errno.EINVAL):
             raise OSError(err, 'Unable to fallocate(%s)' % size)
 
 
+class FsyncWrapper(object):
+
+    def __init__(self):
+        if hasattr(os, 'fdatasync'):
+            self.func_name = 'fdatasync'
+            self.fsync = os.fdatasync
+            self.fcntl_flag = None
+        elif hasattr(fcntl, 'F_FULLFSYNC'):
+            self.func_name = 'fcntl'
+            self.fsync = fcntl.fcntl
+            self.fcntl_flag = fcntl.F_FULLFSYNC
+        else:
+            self.func_name = 'fsync'
+            self.fsync = os.fsync
+            self.fcntl_flag = None
+
+    def __call__(self, fd):
+        args = {
+            'fdatasync': (fd, ),
+            'fsync': (fd, ),
+            'fcntl': (fd, self.fcntl_flag)
+        }
+        return self.fsync(*args[self.func_name])
+
+
+def fsync(fd):
+    """
+    Write buffered changes to disk.
+
+    :param fd: file descriptor
+    """
+
+    global _sys_fsync
+    if _sys_fsync is None:
+        _sys_fsync = FsyncWrapper()
+
+    ret = _sys_fsync(fd)
+    err = ctypes.get_errno()
+    if ret and err != 0:
+        raise OSError(err, 'Unable to fsync(%s)' % fd)
+
+
 def drop_buffer_cache(fd, offset, length):
     """
     Drop 'buffer' cache for the given range of the given file.
@@ -604,7 +648,8 @@ def get_logger(conf, name=None, log_to_console=False, log_route=None,
         try:
             handler = SysLogHandler(address=log_address, facility=facility)
         except socket.error, e:
-            if e.errno != errno.ENOTSOCK:  # Socket operation on non-socket
+            # Either /dev/log isn't a UNIX socket or it does not exist at all
+            if e.errno not in [errno.ENOTSOCK,  errno.ENOENT]:
                 raise e
             handler = SysLogHandler(facility=facility)
     handler.setFormatter(formatter)
@@ -683,7 +728,12 @@ def capture_stdio(logger, **kwargs):
     with open(os.devnull, 'r+b') as nullfile:
         # close stdio (excludes fds open for logging)
         for f in stdio_files:
-            f.flush()
+            # some platforms throw an error when attempting an stdin flush
+            try:
+                f.flush()
+            except IOError:
+                pass
+
             try:
                 os.dup2(nullfile.fileno(), f.fileno())
             except OSError:
