@@ -87,24 +87,23 @@ class AuditorWorker(object):
                     'files/sec: %(frate).2f , bytes/sec: %(brate).2f, '
                     'Total time: %(total).2f, Auditing time: %(audit).2f, '
                     'Rate: %(audit_rate).2f') % {
-                            'type': self.auditor_type,
-                            'start_time': time.ctime(reported),
-                            'passes': self.passes, 'quars': self.quarantines,
-                            'errors': self.errors,
-                            'frate': self.passes / (now - reported),
-                            'brate': self.bytes_processed / (now - reported),
-                            'total': (now - begin), 'audit': time_auditing,
-                            'audit_rate': time_auditing / (now - begin)})
+                        'type': self.auditor_type,
+                        'start_time': time.ctime(reported),
+                        'passes': self.passes, 'quars': self.quarantines,
+                        'errors': self.errors,
+                        'frate': self.passes / (now - reported),
+                        'brate': self.bytes_processed / (now - reported),
+                        'total': (now - begin), 'audit': time_auditing,
+                        'audit_rate': time_auditing / (now - begin)})
                 dump_recon_cache({'object_auditor_stats_%s' %
-                                    self.auditor_type: {
-                                        'errors': self.errors,
-                                        'passes': self.passes,
-                                        'quarantined': self.quarantines,
-                                        'bytes_processed':
-                                            self.bytes_processed,
-                                        'start_time': reported,
-                                        'audit_time': time_auditing}
-                                 }, self.rcache, self.logger)
+                                  self.auditor_type: {
+                                      'errors': self.errors,
+                                      'passes': self.passes,
+                                      'quarantined': self.quarantines,
+                                      'bytes_processed': self.bytes_processed,
+                                      'start_time': reported,
+                                      'audit_time': time_auditing}},
+                                 self.rcache, self.logger)
                 reported = now
                 total_quarantines += self.quarantines
                 total_errors += self.errors
@@ -178,7 +177,8 @@ class AuditorWorker(object):
             self.logger.increment('quarantines')
             self.quarantines += 1
             self.logger.error(_('ERROR Object %(obj)s failed audit and will '
-                'be quarantined: %(err)s'), {'obj': path, 'err': err})
+                                'be quarantined: %(err)s'),
+                              {'obj': path, 'err': err})
             object_server.quarantine_renamer(
                 os.path.join(self.devices, device), path)
             return
@@ -196,8 +196,8 @@ class ObjectAuditor(Daemon):
     def __init__(self, conf, **options):
         self.conf = conf
         self.logger = get_logger(conf, log_route='object-auditor')
-        self.conf_zero_byte_fps = int(conf.get(
-                'zero_byte_files_per_second', 50))
+        self.conf_zero_byte_fps = int(
+            conf.get('zero_byte_files_per_second', 50))
 
     def _sleep(self):
         time.sleep(SLEEP_BETWEEN_AUDITS)
