@@ -41,7 +41,7 @@ class ObjectUpdater(Daemon):
         self.logger = get_logger(conf, log_route='object-updater')
         self.devices = conf.get('devices', '/srv/node')
         self.mount_check = conf.get('mount_check', 'true').lower() in \
-                              ('true', 't', '1', 'on', 'yes', 'y')
+            ('true', 't', '1', 'on', 'yes', 'y')
         self.swift_dir = conf.get('swift_dir', '/etc/swift')
         self.interval = int(conf.get('interval', 300))
         self.container_ring = None
@@ -90,9 +90,10 @@ class ObjectUpdater(Daemon):
                     forkbegin = time.time()
                     self.object_sweep(os.path.join(self.devices, device))
                     elapsed = time.time() - forkbegin
-                    self.logger.info(_('Object update sweep of %(device)s'
-                        ' completed: %(elapsed).02fs, %(success)s successes'
-                        ', %(fail)s failures'),
+                    self.logger.info(
+                        _('Object update sweep of %(device)s'
+                          ' completed: %(elapsed).02fs, %(success)s successes'
+                          ', %(fail)s failures'),
                         {'device': device, 'elapsed': elapsed,
                          'success': self.successes, 'fail': self.failures})
                     sys.exit()
@@ -100,7 +101,7 @@ class ObjectUpdater(Daemon):
                 pids.remove(os.wait()[0])
             elapsed = time.time() - begin
             self.logger.info(_('Object update sweep completed: %.02fs'),
-                    elapsed)
+                             elapsed)
             dump_recon_cache({'object_updater_sweep': elapsed},
                              self.rcache, self.logger)
             if elapsed < self.interval:
@@ -121,8 +122,9 @@ class ObjectUpdater(Daemon):
                 continue
             self.object_sweep(os.path.join(self.devices, device))
         elapsed = time.time() - begin
-        self.logger.info(_('Object update single threaded sweep completed: '
-            '%(elapsed).02fs, %(success)s successes, %(fail)s failures'),
+        self.logger.info(
+            _('Object update single threaded sweep completed: '
+              '%(elapsed).02fs, %(success)s successes, %(fail)s failures'),
             {'elapsed': elapsed, 'success': self.successes,
              'fail': self.failures})
         dump_recon_cache({'object_updater_sweep': elapsed},
@@ -156,6 +158,7 @@ class ObjectUpdater(Daemon):
                         % (update_path))
                     continue
                 if obj_hash == last_obj_hash:
+                    self.logger.increment("unlinks")
                     os.unlink(update_path)
                 else:
                     self.process_object_update(update_path, device)
@@ -180,12 +183,13 @@ class ObjectUpdater(Daemon):
             self.logger.exception(
                 _('ERROR Pickle problem, quarantining %s'), update_path)
             self.logger.increment('quarantines')
-            renamer(update_path, os.path.join(device,
-                'quarantined', 'objects', os.path.basename(update_path)))
+            renamer(update_path, os.path.join(
+                    device, 'quarantined', 'objects',
+                    os.path.basename(update_path)))
             return
         successes = update.get('successes', [])
         part, nodes = self.get_container_ring().get_nodes(
-                                update['account'], update['container'])
+            update['account'], update['container'])
         obj = '/%s/%s/%s' % \
               (update['account'], update['container'], update['obj'])
         success = True
@@ -193,7 +197,7 @@ class ObjectUpdater(Daemon):
         for node in nodes:
             if node['id'] not in successes:
                 status = self.object_update(node, part, update['op'], obj,
-                                        update['headers'])
+                                            update['headers'])
                 if not is_success(status) and status != HTTP_NOT_FOUND:
                     success = False
                 else:
@@ -203,13 +207,14 @@ class ObjectUpdater(Daemon):
             self.successes += 1
             self.logger.increment('successes')
             self.logger.debug(_('Update sent for %(obj)s %(path)s'),
-                {'obj': obj, 'path': update_path})
+                              {'obj': obj, 'path': update_path})
+            self.logger.increment("unlinks")
             os.unlink(update_path)
         else:
             self.failures += 1
             self.logger.increment('failures')
             self.logger.debug(_('Update failed for %(obj)s %(path)s'),
-                {'obj': obj, 'path': update_path})
+                              {'obj': obj, 'path': update_path})
             if new_successes:
                 update['successes'] = successes
                 write_pickle(update, update_path, os.path.join(device, 'tmp'))
@@ -227,12 +232,12 @@ class ObjectUpdater(Daemon):
         try:
             with ConnectionTimeout(self.conn_timeout):
                 conn = http_connect(node['ip'], node['port'], node['device'],
-                    part, op, obj, headers)
+                                    part, op, obj, headers)
             with Timeout(self.node_timeout):
                 resp = conn.getresponse()
                 resp.read()
                 return resp.status
         except (Exception, Timeout):
             self.logger.exception(_('ERROR with remote server '
-                '%(ip)s:%(port)s/%(device)s'), node)
+                                    '%(ip)s:%(port)s/%(device)s'), node)
         return HTTP_INTERNAL_SERVER_ERROR
