@@ -26,28 +26,28 @@
 
 import time
 import functools
+import inspect
 
 from eventlet import spawn_n, GreenPile, Timeout
 from eventlet.queue import Queue, Empty, Full
 from eventlet.timeout import Timeout
-from webob.exc import status_map
-from webob import Request, Response
 
-from swift.common.utils import normalize_timestamp, TRUE_VALUES, public
+from swift.common.utils import normalize_timestamp, config_true_value, public
 from swift.common.bufferedhttp import http_connect
 from swift.common.constraints import MAX_ACCOUNT_NAME_LENGTH
 from swift.common.exceptions import ChunkReadTimeout, ConnectionTimeout
 from swift.common.http import is_informational, is_success, is_redirection, \
     is_server_error, HTTP_OK, HTTP_PARTIAL_CONTENT, HTTP_MULTIPLE_CHOICES, \
     HTTP_BAD_REQUEST, HTTP_NOT_FOUND, HTTP_SERVICE_UNAVAILABLE, \
-    HTTP_INSUFFICIENT_STORAGE
+    HTTP_INSUFFICIENT_STORAGE, HTTP_UNAUTHORIZED
+from swift.common.swob import Request, Response, status_map
 
 
 def update_headers(response, headers):
     """
     Helper function to update headers in the response.
 
-    :param response: webob.Response object
+    :param response: swob.Response object
     :param headers: dictionary headers
     """
     if hasattr(headers, 'items'):
@@ -60,6 +60,17 @@ def update_headers(response, headers):
             response.headers[name] = value
 
 
+def source_key(resp):
+    """
+    Provide the timestamp of the swift http response as a floating
+    point value.  Used as a sort key.
+
+    :param resp: httplib response object
+    """
+    return float(resp.getheader('x-put-timestamp') or
+                 resp.getheader('x-timestamp') or 0)
+
+
 def delay_denial(func):
     """
     Decorator to declare which methods should have any swift.authorize call
@@ -84,6 +95,33 @@ def get_container_memcache_key(account, container):
     return 'container/%s/%s' % (account, container)
 
 
+def headers_to_container_info(headers, status_int=HTTP_OK):
+    """
+    Construct a cacheable dict of container info based on response headers.
+    """
+    headers = dict(headers)
+    return {
+        'status': status_int,
+        'read_acl': headers.get('x-container-read'),
+        'write_acl': headers.get('x-container-write'),
+        'sync_key': headers.get('x-container-sync-key'),
+        'count': headers.get('x-container-object-count'),
+        'bytes': headers.get('x-container-bytes-used'),
+        'versions': headers.get('x-versions-location'),
+        'cors': {
+            'allow_origin': headers.get(
+                'x-container-meta-access-control-allow-origin'),
+            'allow_headers': headers.get(
+                'x-container-meta-access-control-allow-headers'),
+            'max_age': headers.get(
+                'x-container-meta-access-control-max-age')
+        },
+        'meta': dict((key.lower()[17:], value)
+                     for key, value in headers.iteritems()
+                     if key.lower().startswith('x-container-meta-'))
+    }
+
+
 class Controller(object):
     """Base WSGI controller class for the proxy"""
     server_type = 'Base'
@@ -95,17 +133,28 @@ class Controller(object):
         self.account_name = None
         self.app = app
         self.trans_id = '-'
+        self.allowed_methods = set()
+        all_methods = inspect.getmembers(self, predicate=inspect.ismethod)
+        for name, m in all_methods:
+            if getattr(m, 'publicly_accessible', False):
+                self.allowed_methods.add(name)
 
     def transfer_headers(self, src_headers, dst_headers):
-        x_remove = 'x-remove-%s-meta-' % self.server_type.lower()
-        x_meta = 'x-%s-meta-' % self.server_type.lower()
+
+        st = self.server_type.lower()
+        x_remove = 'x-remove-%s-meta-' % st
+        x_remove_read = 'x-remove-%s-read' % st
+        x_remove_write = 'x-remove-%s-write' % st
+        x_meta = 'x-%s-meta-' % st
         dst_headers.update((k.lower().replace('-remove', '', 1), '')
                            for k in src_headers
-                           if k.lower().startswith(x_remove))
+                           if k.lower().startswith(x_remove) or
+                           k.lower() in (x_remove_read, x_remove_write))
+
         dst_headers.update((k.lower(), v)
                            for k, v in src_headers.iteritems()
                            if k.lower() in self.pass_through_headers or
-                              k.lower().startswith(x_meta))
+                           k.lower().startswith(x_meta))
 
     def error_increment(self, node):
         """
@@ -125,7 +174,8 @@ class Controller(object):
         """
         self.error_increment(node)
         self.app.logger.error(_('%(msg)s %(ip)s:%(port)s'),
-            {'msg': msg, 'ip': node['ip'], 'port': node['port']})
+                              {'msg': msg, 'ip': node['ip'],
+                              'port': node['port']})
 
     def exception_occurred(self, node, typ, additional_info):
         """
@@ -210,7 +260,8 @@ class Controller(object):
             try:
                 with ConnectionTimeout(self.app.conn_timeout):
                     conn = http_connect(node['ip'], node['port'],
-                            node['device'], partition, 'HEAD', path, headers)
+                                        node['device'], partition, 'HEAD',
+                                        path, headers)
                 with Timeout(self.app.node_timeout):
                     resp = conn.getresponse()
                     body = resp.read()
@@ -231,7 +282,8 @@ class Controller(object):
                         result_code = -1
             except (Exception, Timeout):
                 self.exception_occurred(node, _('Account'),
-                    _('Trying to get account info for %s') % path)
+                                        _('Trying to get account info for %s')
+                                        % path)
         if result_code == HTTP_NOT_FOUND and autocreate:
             if len(account) > MAX_ACCOUNT_NAME_LENGTH:
                 return None, None, None
@@ -239,10 +291,10 @@ class Controller(object):
                        'X-Trans-Id': self.trans_id,
                        'Connection': 'close'}
             resp = self.make_requests(Request.blank('/v1' + path),
-                self.app.account_ring, partition, 'PUT',
-                path, [headers] * len(nodes))
+                                      self.app.account_ring, partition, 'PUT',
+                                      path, [headers] * len(nodes))
             if not is_success(resp.status_int):
-                self.app.logger.warning('Could not autocreate account %r' % \
+                self.app.logger.warning('Could not autocreate account %r' %
                                         path)
                 return None, None, None
             result_code = HTTP_OK
@@ -252,8 +304,9 @@ class Controller(object):
             else:
                 cache_timeout = self.app.recheck_account_existence * 0.1
             self.app.memcache.set(cache_key,
-                {'status': result_code, 'container_count': container_count},
-                timeout=cache_timeout)
+                                  {'status': result_code,
+                                  'container_count': container_count},
+                                  timeout=cache_timeout)
         if result_code == HTTP_OK:
             return partition, nodes, container_count
         return None, None, None
@@ -266,89 +319,73 @@ class Controller(object):
 
         :param account: account name for the container
         :param container: container name to look up
-        :returns: tuple of (container partition, container nodes, container
-                  read acl, container write acl, container sync key) or (None,
-                  None, None, None, None) if the container does not exist
+        :returns: dict containing at least container partition ('partition'),
+                  container nodes ('containers'), container read
+                  acl ('read_acl'), container write acl ('write_acl'),
+                  and container sync key ('sync_key').
+                  Values are set to None if the container does not exist.
         """
-        partition, nodes = self.app.container_ring.get_nodes(
-                account, container)
+        part, nodes = self.app.container_ring.get_nodes(account, container)
         path = '/%s/%s' % (account, container)
+        container_info = {'status': 0, 'read_acl': None,
+                          'write_acl': None, 'sync_key': None,
+                          'count': None, 'bytes': None,
+                          'versions': None, 'partition': None,
+                          'nodes': None}
         if self.app.memcache:
             cache_key = get_container_memcache_key(account, container)
             cache_value = self.app.memcache.get(cache_key)
             if isinstance(cache_value, dict):
-                status = cache_value['status']
-                read_acl = cache_value['read_acl']
-                write_acl = cache_value['write_acl']
-                sync_key = cache_value.get('sync_key')
-                versions = cache_value.get('versions')
-                if status == HTTP_OK:
-                    return partition, nodes, read_acl, write_acl, sync_key, \
-                            versions
-                elif status == HTTP_NOT_FOUND:
-                    return None, None, None, None, None, None
+                if 'container_size' in cache_value:
+                    cache_value['count'] = cache_value['container_size']
+                if is_success(cache_value['status']):
+                    container_info.update(cache_value)
+                    container_info['partition'] = part
+                    container_info['nodes'] = nodes
+                return container_info
         if not self.account_info(account, autocreate=account_autocreate)[1]:
-            return None, None, None, None, None, None
-        result_code = 0
-        read_acl = None
-        write_acl = None
-        sync_key = None
-        container_size = None
-        versions = None
+            return container_info
         attempts_left = len(nodes)
         headers = {'x-trans-id': self.trans_id, 'Connection': 'close'}
-        iternodes = self.iter_nodes(partition, nodes, self.app.container_ring)
-        while attempts_left > 0:
-            try:
-                node = iternodes.next()
-            except StopIteration:
-                break
-            attempts_left -= 1
+        for node in self.iter_nodes(part, nodes, self.app.container_ring):
             try:
                 with ConnectionTimeout(self.app.conn_timeout):
                     conn = http_connect(node['ip'], node['port'],
-                            node['device'], partition, 'HEAD', path, headers)
+                                        node['device'], part, 'HEAD',
+                                        path, headers)
                 with Timeout(self.app.node_timeout):
                     resp = conn.getresponse()
                     body = resp.read()
-                    if is_success(resp.status):
-                        result_code = HTTP_OK
-                        read_acl = resp.getheader('x-container-read')
-                        write_acl = resp.getheader('x-container-write')
-                        sync_key = resp.getheader('x-container-sync-key')
-                        container_size = \
-                            resp.getheader('X-Container-Object-Count')
-                        versions = resp.getheader('x-versions-location')
-                        break
-                    elif resp.status == HTTP_NOT_FOUND:
-                        if result_code == 0:
-                            result_code = HTTP_NOT_FOUND
-                        elif result_code != HTTP_NOT_FOUND:
-                            result_code = -1
-                    elif resp.status == HTTP_INSUFFICIENT_STORAGE:
+                if is_success(resp.status):
+                    container_info.update(
+                        headers_to_container_info(resp.getheaders()))
+                    break
+                elif resp.status == HTTP_NOT_FOUND:
+                    container_info['status'] = HTTP_NOT_FOUND
+                else:
+                    container_info['status'] = -1
+                    if resp.status == HTTP_INSUFFICIENT_STORAGE:
                         self.error_limit(node)
-                        continue
-                    else:
-                        result_code = -1
             except (Exception, Timeout):
-                self.exception_occurred(node, _('Container'),
+                self.exception_occurred(
+                    node, _('Container'),
                     _('Trying to get container info for %s') % path)
-        if self.app.memcache and result_code in (HTTP_OK, HTTP_NOT_FOUND):
-            if result_code == HTTP_OK:
-                cache_timeout = self.app.recheck_container_existence
-            else:
-                cache_timeout = self.app.recheck_container_existence * 0.1
-            self.app.memcache.set(cache_key,
-                                  {'status': result_code,
-                                   'read_acl': read_acl,
-                                   'write_acl': write_acl,
-                                   'sync_key': sync_key,
-                                   'container_size': container_size,
-                                   'versions': versions},
-                                  timeout=cache_timeout)
-        if result_code == HTTP_OK:
-            return partition, nodes, read_acl, write_acl, sync_key, versions
-        return None, None, None, None, None, None
+            attempts_left -= 1
+            if attempts_left <= 0:
+                break
+        if self.app.memcache:
+            if container_info['status'] == HTTP_OK:
+                self.app.memcache.set(
+                    cache_key, container_info,
+                    timeout=self.app.recheck_container_existence)
+            elif container_info['status'] == HTTP_NOT_FOUND:
+                self.app.memcache.set(
+                    cache_key, container_info,
+                    timeout=self.app.recheck_container_existence * 0.1)
+        if container_info['status'] == HTTP_OK:
+            container_info['partition'] = part
+            container_info['nodes'] = nodes
+        return container_info
 
     def iter_nodes(self, partition, nodes, ring):
         """
@@ -381,23 +418,23 @@ class Controller(object):
             try:
                 with ConnectionTimeout(self.app.conn_timeout):
                     conn = http_connect(node['ip'], node['port'],
-                            node['device'], part, method, path,
-                            headers=headers, query_string=query)
+                                        node['device'], part, method, path,
+                                        headers=headers, query_string=query)
                     conn.node = node
                 with Timeout(self.app.node_timeout):
                     resp = conn.getresponse()
                     if not is_informational(resp.status) and \
-                       not is_server_error(resp.status):
+                            not is_server_error(resp.status):
                         return resp.status, resp.reason, resp.read()
                     elif resp.status == HTTP_INSUFFICIENT_STORAGE:
                         self.error_limit(node)
             except (Exception, Timeout):
                 self.exception_occurred(node, self.server_type,
-                    _('Trying to %(method)s %(path)s') %
-                    {'method': method, 'path': path})
+                                        _('Trying to %(method)s %(path)s') %
+                                        {'method': method, 'path': path})
 
     def make_requests(self, req, ring, part, method, path, headers,
-                    query_string=''):
+                      query_string=''):
         """
         Sends an HTTP request to multiple nodes and aggregates the results.
         It attempts the primary nodes concurrently, then iterates over the
@@ -405,7 +442,7 @@ class Controller(object):
 
         :param headers: a list of dicts, where each dict represents one
                         backend request that should be made.
-        :returns: a webob Response object
+        :returns: a swob.Response object
         """
         start_nodes = ring.get_part_nodes(part)
         nodes = self.iter_nodes(part, start_nodes, ring)
@@ -418,7 +455,7 @@ class Controller(object):
             response.append((HTTP_SERVICE_UNAVAILABLE, '', ''))
         statuses, reasons, bodies = zip(*response)
         return self.best_response(req, statuses, reasons, bodies,
-                  '%s %s' % (self.server_type, req.method))
+                                  '%s %s' % (self.server_type, req.method))
 
     def best_response(self, req, statuses, reasons, bodies, server_type,
                       etag=None):
@@ -426,13 +463,13 @@ class Controller(object):
         Given a list of responses from several servers, choose the best to
         return to the API.
 
-        :param req: webob.Request object
+        :param req: swob.Request object
         :param statuses: list of statuses returned
         :param reasons: list of reasons for each status
         :param bodies: bodies of each response
         :param server_type: type of server the responses came from
         :param etag: etag
-        :returns: webob.Response object with the correct status, body, etc. set
+        :returns: swob.Response object with the correct status, body, etc. set
         """
         resp = Response(request=req)
         if len(statuses):
@@ -444,7 +481,6 @@ class Controller(object):
                     status_index = statuses.index(status)
                     resp.status = '%s %s' % (status, reasons[status_index])
                     resp.body = bodies[status_index]
-                    resp.content_type = 'text/html'
                     if etag:
                         resp.headers['etag'] = etag.strip('"')
                     return resp
@@ -495,7 +531,7 @@ class Controller(object):
                 success = False
             except (Exception, Timeout):
                 self.exception_occurred(node, _('Object'),
-                   _('Trying to read during GET'))
+                                        _('Trying to read during GET'))
                 success = False
         finally:
             # Ensure the queue getter gets a terminator.
@@ -556,25 +592,31 @@ class Controller(object):
         except Exception:
             pass
 
+    def is_good_source(self, src):
+        """
+        Indicates whether or not the request made to the backend found
+        what it was looking for.
+        """
+        return is_success(src.status) or is_redirection(src.status)
+
     def GETorHEAD_base(self, req, server_type, partition, nodes, path,
                        attempts):
         """
         Base handler for HTTP GET or HEAD requests.
 
-        :param req: webob.Request object
+        :param req: swob.Request object
         :param server_type: server type
         :param partition: partition
         :param nodes: nodes
         :param path: path for the request
         :param attempts: number of attempts to try
-        :returns: webob.Response object
+        :returns: swob.Response object
         """
         statuses = []
         reasons = []
         bodies = []
-        source = None
         sources = []
-        newest = req.headers.get('x-newest', 'f').lower() in TRUE_VALUES
+        newest = config_true_value(req.headers.get('x-newest', 'f'))
         nodes = iter(nodes)
         while len(statuses) < attempts:
             try:
@@ -587,99 +629,114 @@ class Controller(object):
                 with ConnectionTimeout(self.app.conn_timeout):
                     headers = dict(req.headers)
                     headers['Connection'] = 'close'
-                    conn = http_connect(node['ip'], node['port'],
-                        node['device'], partition, req.method, path,
-                        headers=headers,
+                    conn = http_connect(
+                        node['ip'], node['port'], node['device'], partition,
+                        req.method, path, headers=headers,
                         query_string=req.query_string)
                 with Timeout(self.app.node_timeout):
                     possible_source = conn.getresponse()
                     # See NOTE: swift_conn at top of file about this.
                     possible_source.swift_conn = conn
             except (Exception, Timeout):
-                self.exception_occurred(node, server_type,
-                    _('Trying to %(method)s %(path)s') %
+                self.exception_occurred(
+                    node, server_type, _('Trying to %(method)s %(path)s') %
                     {'method': req.method, 'path': req.path})
                 continue
-            if possible_source.status == HTTP_INSUFFICIENT_STORAGE:
-                self.error_limit(node)
-                continue
-            if is_success(possible_source.status) or \
-               is_redirection(possible_source.status):
+            if self.is_good_source(possible_source):
                 # 404 if we know we don't have a synced copy
                 if not float(possible_source.getheader('X-PUT-Timestamp', 1)):
                     statuses.append(HTTP_NOT_FOUND)
                     reasons.append('')
                     bodies.append('')
-                    possible_source.read()
-                    continue
-                if newest:
-                    if sources:
-                        ts = float(source.getheader('x-put-timestamp') or
-                                   source.getheader('x-timestamp') or 0)
-                        pts = float(
-                            possible_source.getheader('x-put-timestamp') or
-                            possible_source.getheader('x-timestamp') or 0)
-                        if pts > ts:
-                            sources.insert(0, possible_source)
-                        else:
-                            sources.append(possible_source)
-                    else:
-                        sources.insert(0, possible_source)
-                    source = sources[0]
-                    statuses.append(source.status)
-                    reasons.append(source.reason)
-                    bodies.append('')
-                    continue
+                    self.close_swift_conn(possible_source)
                 else:
-                    source = possible_source
-                    break
-            statuses.append(possible_source.status)
-            reasons.append(possible_source.reason)
-            bodies.append(possible_source.read())
-            if is_server_error(possible_source.status):
-                self.error_occurred(node, _('ERROR %(status)d %(body)s ' \
-                    'From %(type)s Server') %
-                    {'status': possible_source.status,
-                    'body': bodies[-1][:1024], 'type': server_type})
-        if source:
+                    statuses.append(possible_source.status)
+                    reasons.append(possible_source.reason)
+                    bodies.append('')
+                    sources.append(possible_source)
+                    if not newest:  # one good source is enough
+                        break
+            else:
+                statuses.append(possible_source.status)
+                reasons.append(possible_source.reason)
+                bodies.append(possible_source.read())
+                if possible_source.status == HTTP_INSUFFICIENT_STORAGE:
+                    self.error_limit(node)
+                elif is_server_error(possible_source.status):
+                    self.error_occurred(node, _('ERROR %(status)d %(body)s '
+                                                'From %(type)s Server') %
+                                        {'status': possible_source.status,
+                                         'body': bodies[-1][:1024],
+                                         'type': server_type})
+        if sources:
+            sources.sort(key=source_key)
+            source = sources.pop()
+            for src in sources:
+                self.close_swift_conn(src)
+            res = Response(request=req, conditional_response=True)
             if req.method == 'GET' and \
-               source.status in (HTTP_OK, HTTP_PARTIAL_CONTENT):
-                if newest:
-                    # we need to close all hanging swift_conns
-                    sources.pop(0)
-                    for src in sources:
-                        self.close_swift_conn(src)
-
-                res = Response(request=req, conditional_response=True)
+                    source.status in (HTTP_OK, HTTP_PARTIAL_CONTENT):
                 res.app_iter = self._make_app_iter(node, source)
                 # See NOTE: swift_conn at top of file about this.
                 res.swift_conn = source.swift_conn
-                update_headers(res, source.getheaders())
-                # Used by container sync feature
-                if res.environ is None:
-                    res.environ = dict()
-                res.environ['swift_x_timestamp'] = \
-                    source.getheader('x-timestamp')
-                update_headers(res, {'accept-ranges': 'bytes'})
-                res.status = source.status
-                res.content_length = source.getheader('Content-Length')
-                if source.getheader('Content-Type'):
-                    res.charset = None
-                    res.content_type = source.getheader('Content-Type')
-                return res
-            elif is_success(source.status) or is_redirection(source.status):
-                res = status_map[source.status](request=req)
-                update_headers(res, source.getheaders())
-                # Used by container sync feature
-                if res.environ is None:
-                    res.environ = dict()
-                res.environ['swift_x_timestamp'] = \
-                    source.getheader('x-timestamp')
-                update_headers(res, {'accept-ranges': 'bytes'})
-                res.content_length = source.getheader('Content-Length')
-                if source.getheader('Content-Type'):
-                    res.charset = None
-                    res.content_type = source.getheader('Content-Type')
-                return res
+            res.status = source.status
+            update_headers(res, source.getheaders())
+            if not res.environ:
+                res.environ = {}
+            res.environ['swift_x_timestamp'] = \
+                source.getheader('x-timestamp')
+            res.accept_ranges = 'bytes'
+            res.content_length = source.getheader('Content-Length')
+            if source.getheader('Content-Type'):
+                res.charset = None
+                res.content_type = source.getheader('Content-Type')
+            return res
         return self.best_response(req, statuses, reasons, bodies,
                                   '%s %s' % (server_type, req.method))
+
+    def OPTIONS_base(self, req):
+        """
+        Base handler for OPTIONS requests
+
+        :param req: swob.Request object
+        :returns: swob.Response object
+        """
+        headers = {'Allow': ', '.join(self.allowed_methods)}
+        resp = Response(status=200, request=req,
+                        headers=headers)
+        req_origin_value = req.headers.get('Origin', None)
+        if not req_origin_value:
+            # NOT a CORS request
+            return resp
+
+        # CORS preflight request
+        try:
+            container_info = \
+                self.container_info(self.account_name, self.container_name)
+        except AttributeError:
+            container_info = {}
+        cors = container_info.get('cors', {})
+        allowed_origins = set()
+        if cors.get('allow_origin'):
+            allowed_origins.update(cors['allow_origin'].split(' '))
+        if self.app.cors_allow_origin:
+            allowed_origins.update(self.app.cors_allow_origin)
+        if (req_origin_value not in allowed_origins and
+                '*' not in allowed_origins) or (
+                req.headers.get('Access-Control-Request-Method') not in
+                self.allowed_methods):
+            resp.status = HTTP_UNAUTHORIZED
+            return resp  # CORS preflight request that isn't valid
+        headers['access-control-allow-origin'] = req_origin_value
+        if cors.get('max_age', None) is not None:
+            headers['access-control-max-age'] = '%d' % cors.get('max_age')
+        headers['access-control-allow-methods'] = ', '.join(
+            self.allowed_methods)
+        if cors.get('allow_headers'):
+            headers['access-control-allow-headers'] = cors.get('allow_headers')
+        resp.headers = headers
+        return resp
+
+    @public
+    def OPTIONS(self, req):
+        return self.OPTIONS_base(req)
