@@ -39,10 +39,6 @@ from random import shuffle
 from eventlet import sleep, GreenPile, Timeout
 from eventlet.queue import Queue
 from eventlet.timeout import Timeout
-from webob.exc import HTTPAccepted, HTTPBadRequest, HTTPNotFound, \
-    HTTPPreconditionFailed, HTTPRequestEntityTooLarge, HTTPRequestTimeout, \
-    HTTPServerError, HTTPServiceUnavailable
-from webob import Request, Response
 
 from swift.common.utils import ContextPool, normalize_timestamp, TRUE_VALUES, \
     public
@@ -55,8 +51,12 @@ from swift.common.exceptions import ChunkReadTimeout, \
 from swift.common.http import is_success, is_client_error, HTTP_CONTINUE, \
     HTTP_CREATED, HTTP_MULTIPLE_CHOICES, HTTP_NOT_FOUND, \
     HTTP_INTERNAL_SERVER_ERROR, HTTP_SERVICE_UNAVAILABLE, \
-    HTTP_INSUFFICIENT_STORAGE, HTTPClientDisconnect
+    HTTP_INSUFFICIENT_STORAGE
 from swift.proxy.controllers.base import Controller, delay_denial
+from swift.common.swob import HTTPAccepted, HTTPBadRequest, HTTPNotFound, \
+    HTTPPreconditionFailed, HTTPRequestEntityTooLarge, HTTPRequestTimeout, \
+    HTTPServerError, HTTPServiceUnavailable, Request, Response, \
+    HTTPClientDisconnect
 
 
 class SegmentedIterable(object):
@@ -72,7 +72,7 @@ class SegmentedIterable(object):
     :param listing: The listing of object segments to iterate over; this may
                     be an iterator or list that returns dicts with 'name' and
                     'bytes' keys.
-    :param response: The webob.Response this iterable is associated with, if
+    :param response: The swob.Response this iterable is associated with, if
                      any (default: None)
     """
 
@@ -278,8 +278,9 @@ class ObjectController(Controller):
 
     def GETorHEAD(self, req):
         """Handle HTTP GET or HEAD requests."""
-        _junk, _junk, req.acl, _junk, _junk, object_versions = \
-            self.container_info(self.account_name, self.container_name)
+        container_info = self.container_info(self.account_name,
+                                             self.container_name)
+        req.acl = container_info['read_acl']
         if 'swift.authorize' in req.environ:
             aresp = req.environ['swift.authorize'](req)
             if aresp:
@@ -326,11 +327,11 @@ class ObjectController(Controller):
                 resp = Response(headers=resp.headers, request=req,
                                 conditional_response=True)
                 if req.method == 'HEAD':
-                    # These shenanigans are because webob translates the HEAD
-                    # request into a webob EmptyResponse for the body, which
+                    # These shenanigans are because swob translates the HEAD
+                    # request into a swob EmptyResponse for the body, which
                     # has a len, which eventlet translates as needing a
                     # content-length header added. So we call the original
-                    # webob resp for the headers but return an empty iterator
+                    # swob resp for the headers but return an empty iterator
                     # for the body.
 
                     def head_response(environ, start_response):
@@ -413,9 +414,12 @@ class ObjectController(Controller):
             error_response = check_metadata(req, 'object')
             if error_response:
                 return error_response
-            container_partition, containers, _junk, req.acl, _junk, _junk = \
-                self.container_info(self.account_name, self.container_name,
-                    account_autocreate=self.app.account_autocreate)
+            container_info = self.container_info(
+                self.account_name, self.container_name,
+                account_autocreate=self.app.account_autocreate)
+            container_partition = container_info['partition']
+            containers = container_info['nodes']
+            req.acl = container_info['write_acl']
             if 'swift.authorize' in req.environ:
                 aresp = req.environ['swift.authorize'](req)
                 if aresp:
@@ -498,10 +502,14 @@ class ObjectController(Controller):
     @delay_denial
     def PUT(self, req):
         """HTTP PUT request handler."""
-        (container_partition, containers, _junk, req.acl,
-         req.environ['swift_sync_key'], object_versions) = \
-            self.container_info(self.account_name, self.container_name,
-                account_autocreate=self.app.account_autocreate)
+        container_info = self.container_info(
+            self.account_name, self.container_name,
+            account_autocreate=self.app.account_autocreate)
+        container_partition = container_info['partition']
+        containers = container_info['nodes']
+        req.acl = container_info['write_acl']
+        req.environ['swift_sync_key'] = container_info['sync_key']
+        object_versions = container_info['versions']
         if 'swift.authorize' in req.environ:
             aresp = req.environ['swift.authorize'](req)
             if aresp:
@@ -776,9 +784,13 @@ class ObjectController(Controller):
     @delay_denial
     def DELETE(self, req):
         """HTTP DELETE request handler."""
-        (container_partition, containers, _junk, req.acl,
-         req.environ['swift_sync_key'], object_versions) = \
-            self.container_info(self.account_name, self.container_name)
+        container_info = self.container_info(self.account_name,
+                                             self.container_name)
+        container_partition = container_info['partition']
+        containers = container_info['nodes']
+        req.acl = container_info['write_acl']
+        req.environ['swift_sync_key'] = container_info['sync_key']
+        object_versions = container_info['versions']
         if object_versions:
             # this is a version manifest and needs to be handled differently
             lcontainer = object_versions.split('/')[0]
@@ -824,9 +836,11 @@ class ObjectController(Controller):
                 self.container_name = lcontainer
                 self.object_name = last_item['name']
                 new_del_req = Request.blank(copy_path, environ=req.environ)
-                (container_partition, containers,
-                    _junk, new_del_req.acl, _junk, _junk) = \
-                    self.container_info(self.account_name, self.container_name)
+                container_info = self.container_info(self.account_name,
+                                                     self.container_name)
+                container_partition = container_info['partition']
+                containers = container_info['nodes']
+                new_del_req.acl = container_info['write_acl']
                 new_del_req.path_info = copy_path
                 req = new_del_req
         if 'swift.authorize' in req.environ:
