@@ -1,4 +1,4 @@
-# Copyright (c) 2010-2011 OpenStack, LLC.
+# Copyright (c) 2010-2012 OpenStack, LLC.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,29 +15,35 @@
 
 import unittest
 
-from webob import Request
-
+from swift.common.swob import Request, Response
 from swift.common.middleware import catch_errors
+from swift.common.utils import get_logger
 
 class FakeApp(object):
     def __init__(self, error=False):
         self.error = error
 
     def __call__(self, env, start_response):
+        if 'swift.trans_id' not in env:
+            raise Exception('Trans id should always be in env')
         if self.error:
-            raise Exception('augh!')
-        return "FAKE APP"
+            raise Exception('An error occurred')
+        return ["FAKE APP"]
 
 def start_response(*args):
     pass
 
 class TestCatchErrors(unittest.TestCase):
 
+    def setUp(self):
+        self.logger = get_logger({})
+        self.logger.txn_id = None
+
     def test_catcherrors_passthrough(self):
         app = catch_errors.CatchErrorMiddleware(FakeApp(), {})
         req = Request.blank('/', environ={'REQUEST_METHOD': 'GET'})
         resp = app(req.environ, start_response)
-        self.assertEquals(resp, 'FAKE APP')
+        self.assertEquals(resp, ['FAKE APP'])
 
     def test_catcherrors(self):
         app = catch_errors.CatchErrorMiddleware(FakeApp(True), {})
@@ -45,28 +51,23 @@ class TestCatchErrors(unittest.TestCase):
         resp = app(req.environ, start_response)
         self.assertEquals(resp, ['An error occurred'])
 
-    def test_trans_id_header(self):
-
+    def test_trans_id_header_pass(self):
+        self.assertEquals(self.logger.txn_id, None)
         def start_response(status, headers):
             self.assert_('x-trans-id' in (x[0] for x in headers))
         app = catch_errors.CatchErrorMiddleware(FakeApp(), {})
-        req = Request.blank('/v1/a')
-        app(req.environ, start_response)
-        app = catch_errors.CatchErrorMiddleware(FakeApp(), {})
-        req = Request.blank('/v1/a/c')
-        app(req.environ, start_response)
-        app = catch_errors.CatchErrorMiddleware(FakeApp(), {})
         req = Request.blank('/v1/a/c/o')
         app(req.environ, start_response)
-        app = catch_errors.CatchErrorMiddleware(FakeApp(True), {})
-        req = Request.blank('/v1/a')
-        app(req.environ, start_response)
-        app = catch_errors.CatchErrorMiddleware(FakeApp(True), {})
-        req = Request.blank('/v1/a/c')
-        app(req.environ, start_response)
+        self.assertEquals(len(self.logger.txn_id), 34) # 32 hex + 'tx'
+
+    def test_trans_id_header_fail(self):
+        self.assertEquals(self.logger.txn_id, None)
+        def start_response(status, headers):
+            self.assert_('x-trans-id' in (x[0] for x in headers))
         app = catch_errors.CatchErrorMiddleware(FakeApp(True), {})
         req = Request.blank('/v1/a/c/o')
         app(req.environ, start_response)
+        self.assertEquals(len(self.logger.txn_id), 34)
 
 if __name__ == '__main__':
     unittest.main()
