@@ -20,8 +20,7 @@ from contextlib import contextmanager
 from StringIO import StringIO
 from time import time
 
-from webob import Request, Response
-
+from swift.common.swob import Request, Response
 from swift.common.middleware import tempauth, formpost
 
 
