@@ -20,8 +20,7 @@ except ImportError:
 import unittest
 from contextlib import contextmanager
 
-from webob import Request, Response
-
+from swift.common.swob import Request, Response
 from swift.common.middleware import staticweb
 from test.unit import FakeLogger
 
