@@ -21,6 +21,7 @@ import errno
 import logging
 import mimetools
 import os
+import random
 import re
 import socket
 import sys
@@ -36,8 +37,8 @@ from tempfile import TemporaryFile, NamedTemporaryFile
 
 from eventlet import sleep
 
-from swift.common.exceptions import Timeout, MessageTimeout, \
-        ConnectionTimeout
+from swift.common.exceptions import (Timeout, MessageTimeout,
+                                     ConnectionTimeout)
 from swift.common import utils
 
 
@@ -82,6 +83,17 @@ class MockOs():
             return getattr(os, name)
 
 
+class MockUdpSocket():
+    def __init__(self):
+        self.sent = []
+
+    def sendto(self, data, target):
+        self.sent.append((data, target))
+
+    def close(self):
+        pass
+
+
 class MockSys():
 
     def __init__(self):
@@ -197,21 +209,30 @@ class TestUtils(unittest.TestCase):
     def test_validate_device_partition(self):
         """ Test swift.common.utils.validate_device_partition """
         utils.validate_device_partition('foo', 'bar')
-        self.assertRaises(ValueError, utils.validate_device_partition, '', '')
-        self.assertRaises(ValueError, utils.validate_device_partition, '', 'foo')
-        self.assertRaises(ValueError, utils.validate_device_partition, 'foo', '')
-        self.assertRaises(ValueError, utils.validate_device_partition, 'foo/bar', 'foo')
-        self.assertRaises(ValueError, utils.validate_device_partition, 'foo', 'foo/bar')
-        self.assertRaises(ValueError, utils.validate_device_partition, '.', 'foo')
-        self.assertRaises(ValueError, utils.validate_device_partition, '..', 'foo')
-        self.assertRaises(ValueError, utils.validate_device_partition, 'foo', '.')
-        self.assertRaises(ValueError, utils.validate_device_partition, 'foo', '..')
+        self.assertRaises(ValueError,
+                          utils.validate_device_partition, '', '')
+        self.assertRaises(ValueError,
+                          utils.validate_device_partition, '', 'foo')
+        self.assertRaises(ValueError,
+                          utils.validate_device_partition, 'foo', '')
+        self.assertRaises(ValueError,
+                          utils.validate_device_partition, 'foo/bar', 'foo')
+        self.assertRaises(ValueError,
+                          utils.validate_device_partition, 'foo', 'foo/bar')
+        self.assertRaises(ValueError,
+                          utils.validate_device_partition, '.', 'foo')
+        self.assertRaises(ValueError,
+                          utils.validate_device_partition, '..', 'foo')
+        self.assertRaises(ValueError,
+                          utils.validate_device_partition, 'foo', '.')
+        self.assertRaises(ValueError,
+                          utils.validate_device_partition, 'foo', '..')
         try:
-            utils.validate_device_partition,('o\nn e', 'foo')
+            utils.validate_device_partition('o\nn e', 'foo')
         except ValueError, err:
             self.assertEquals(str(err), 'Invalid device: o%0An%20e')
         try:
-            utils.validate_device_partition,('foo', 'o\nn e')
+            utils.validate_device_partition('foo', 'o\nn e')
         except ValueError, err:
             self.assertEquals(str(err), 'Invalid partition: o%0An%20e')
 
@@ -243,21 +264,21 @@ class TestUtils(unittest.TestCase):
         self.assertEquals(sio.getvalue(), 'STDOUT: test2\nSTDOUT: test4\n')
         print >> sys.stderr, 'test6'
         self.assertEquals(sio.getvalue(), 'STDOUT: test2\nSTDOUT: test4\n'
-            'STDOUT: test6\n')
+                          'STDOUT: test6\n')
         sys.stderr = orig_stderr
         print 'test8'
         self.assertEquals(sio.getvalue(), 'STDOUT: test2\nSTDOUT: test4\n'
-            'STDOUT: test6\n')
+                          'STDOUT: test6\n')
         lfo.writelines(['a', 'b', 'c'])
         self.assertEquals(sio.getvalue(), 'STDOUT: test2\nSTDOUT: test4\n'
-            'STDOUT: test6\nSTDOUT: a#012b#012c\n')
+                          'STDOUT: test6\nSTDOUT: a#012b#012c\n')
         lfo.close()
         lfo.write('d')
         self.assertEquals(sio.getvalue(), 'STDOUT: test2\nSTDOUT: test4\n'
-            'STDOUT: test6\nSTDOUT: a#012b#012c\nSTDOUT: d\n')
+                          'STDOUT: test6\nSTDOUT: a#012b#012c\nSTDOUT: d\n')
         lfo.flush()
         self.assertEquals(sio.getvalue(), 'STDOUT: test2\nSTDOUT: test4\n'
-            'STDOUT: test6\nSTDOUT: a#012b#012c\nSTDOUT: d\n')
+                          'STDOUT: test6\nSTDOUT: a#012b#012c\nSTDOUT: d\n')
         got_exc = False
         try:
             for line in lfo:
@@ -503,7 +524,7 @@ class TestUtils(unittest.TestCase):
 
     def test_storage_directory(self):
         self.assertEquals(utils.storage_directory('objects', '1', 'ABCDEF'),
-                'objects/1/DEF/ABCDEF')
+                          'objects/1/DEF/ABCDEF')
 
     def test_whataremyips(self):
         myips = utils.whataremyips()
@@ -522,7 +543,8 @@ class TestUtils(unittest.TestCase):
         self.assertEquals(utils.hash_path('a', 'c', 'o', raw_digest=False),
                           '06fbf0b514e5199dfc4e00f42eb5ea83')
         self.assertEquals(utils.hash_path('a', 'c', 'o', raw_digest=True),
-                  '\x06\xfb\xf0\xb5\x14\xe5\x19\x9d\xfcN\x00\xf4.\xb5\xea\x83')
+                          '\x06\xfb\xf0\xb5\x14\xe5\x19\x9d\xfcN'
+                          '\x00\xf4.\xb5\xea\x83')
         self.assertRaises(ValueError, utils.hash_path, 'a', object='o')
 
     def test_load_libc_function(self):
@@ -858,7 +880,8 @@ log_name = %(yarr)s'''
         for goodurl in ('http://1.1.1.1/v1/a/c/o',
                         'http://1.1.1.1:8080/a/c/o',
                         'http://2.2.2.2/a/c/o',
-                        'https://1.1.1.1/v1/a/c/o'):
+                        'https://1.1.1.1/v1/a/c/o',
+                        ''):
             self.assertEquals(utils.validate_sync_to(goodurl,
                                                      ['1.1.1.1', '2.2.2.2']),
                               None)
@@ -870,14 +893,26 @@ log_name = %(yarr)s'''
                        'http://1.1.1.1/v1/a/c/o?query=param',
                        'http://1.1.1.1/v1/a/c/o?query=param#frag',
                        'http://1.1.1.2/v1/a/c/o'):
-            self.assertNotEquals(utils.validate_sync_to(badurl,
-                                                       ['1.1.1.1', '2.2.2.2']),
-                                 None)
+            self.assertNotEquals(
+                utils.validate_sync_to(badurl, ['1.1.1.1', '2.2.2.2']),
+                None)
 
     def test_TRUE_VALUES(self):
         for v in utils.TRUE_VALUES:
             self.assertEquals(v, v.lower())
 
+    def test_config_true_value(self):
+        orig_trues = utils.TRUE_VALUES
+        try:
+            utils.TRUE_VALUES = 'hello world'.split()
+            for val in 'hello world HELLO WORLD'.split():
+                self.assertTrue(utils.config_true_value(val) is True)
+            self.assertTrue(utils.config_true_value(True) is True)
+            self.assertTrue(utils.config_true_value('foo') is False)
+            self.assertTrue(utils.config_true_value(False) is False)
+        finally:
+            utils.TRUE_VALUES = orig_trues
+
     def test_streq_const_time(self):
         self.assertTrue(utils.streq_const_time('abc123', 'abc123'))
         self.assertFalse(utils.streq_const_time('a', 'aaaaa'))
@@ -906,7 +941,8 @@ class TestStatsdLogging(unittest.TestCase):
         logger = utils.get_logger({'log_statsd_host': 'some.host.com'},
                                   'some-name', log_route='some-route')
         # white-box construction validation
-        self.assert_(isinstance(logger.logger.statsd_client, utils.StatsdClient))
+        self.assert_(isinstance(logger.logger.statsd_client,
+                                utils.StatsdClient))
         self.assertEqual(logger.logger.statsd_client._host, 'some.host.com')
         self.assertEqual(logger.logger.statsd_client._port, 8125)
         self.assertEqual(logger.logger.statsd_client._prefix, 'some-name.')
@@ -934,14 +970,36 @@ class TestStatsdLogging(unittest.TestCase):
         self.assertEqual(logger.logger.statsd_client._prefix, 'tomato.sauce.')
         self.assertEqual(logger.logger.statsd_client._host, 'another.host.com')
         self.assertEqual(logger.logger.statsd_client._port, 9876)
-        self.assertEqual(logger.logger.statsd_client._default_sample_rate, 0.75)
+        self.assertEqual(logger.logger.statsd_client._default_sample_rate,
+                         0.75)
+
+    def test_sample_rates(self):
+        logger = utils.get_logger({'log_statsd_host': 'some.host.com'})
+
+        mock_socket = MockUdpSocket()
+        # encapsulation? what's that?
+        statsd_client = logger.logger.statsd_client
+        self.assertTrue(statsd_client.random is random.random)
+
+        statsd_client._open_socket = lambda *_: mock_socket
+        statsd_client.random = lambda: 0.50001
+
+        logger.increment('tribbles', sample_rate=0.5)
+        self.assertEqual(len(mock_socket.sent), 0)
+
+        statsd_client.random = lambda: 0.49999
+        logger.increment('tribbles', sample_rate=0.5)
+        self.assertEqual(len(mock_socket.sent), 1)
+
+        payload = mock_socket.sent[0][0]
+        self.assertTrue(payload.endswith("|@0.5"))
 
 
 class TestStatsdLoggingDelegation(unittest.TestCase):
     def setUp(self):
-        self.port = 9177
         self.sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
-        self.sock.bind(('localhost', self.port))
+        self.sock.bind(('localhost', 0))
+        self.port = self.sock.getsockname()[1]
         self.queue = Queue()
         self.reader_thread = Thread(target=self.statsd_reader)
         self.reader_thread.setDaemon(1)
@@ -959,7 +1017,6 @@ class TestStatsdLoggingDelegation(unittest.TestCase):
         self.reader_thread.join(timeout=4)
         self.sock.close()
         del self.logger
-        time.sleep(0.15)  # avoid occasional "Address already in use"?
 
     def statsd_reader(self):
         while True:
@@ -1003,7 +1060,8 @@ class TestStatsdLoggingDelegation(unittest.TestCase):
         # Delegate methods are no-ops
         self.assertEqual(None, logger.update_stats('foo', 88))
         self.assertEqual(None, logger.update_stats('foo', 88, 0.57))
-        self.assertEqual(None, logger.update_stats('foo', 88, sample_rate=0.61))
+        self.assertEqual(None, logger.update_stats('foo', 88,
+                                                   sample_rate=0.61))
         self.assertEqual(None, logger.increment('foo'))
         self.assertEqual(None, logger.increment('foo', 0.57))
         self.assertEqual(None, logger.increment('foo', sample_rate=0.61))
@@ -1175,7 +1233,7 @@ class TestStatsdLoggingDelegation(unittest.TestCase):
             self.assertEquals(logger.thread_locals, ('5678', '5.6.7.8'))
         finally:
             logger.thread_locals = orig_thread_locals
-        
+
 
 if __name__ == '__main__':
     unittest.main()
