@@ -29,10 +29,11 @@ from collections import defaultdict
 from urllib import quote
 
 from eventlet import sleep
-from webob import Request
 
+from swift.common.swob import Request
 from swift.common import wsgi
 
+
 class TestWSGI(unittest.TestCase):
     """ Tests for swift.common.wsgi """
 
@@ -217,6 +218,10 @@ class TestWSGI(unittest.TestCase):
             {'QUERY_STRING': 'original'}, 'GET', 'path?')
         self.assertEquals(r.query_string, '')
 
+    def test_pre_auth_req_with_body(self):
+        r = wsgi.make_pre_authed_request(
+            {'QUERY_STRING': 'original'}, 'GET', 'path', 'the body')
+        self.assertEquals(r.body, 'the body')
 
 if __name__ == '__main__':
     unittest.main()
