@@ -23,8 +23,8 @@ from tempfile import mkdtemp
 
 from eventlet import spawn, Timeout, listen
 import simplejson
-from webob import Request
 
+from swift.common.swob import Request
 from swift.container import server as container_server
 from swift.common.utils import normalize_timestamp, mkdirs
 
@@ -644,6 +644,14 @@ class TestContainerController(unittest.TestCase):
         self.assertEquals(resp.content_type, 'text/plain')
         self.assertEquals(resp.body, plain_body)
 
+        # test unknown format uses default plain
+        req = Request.blank('/sda1/p/a/plainc?format=somethingelse',
+                environ={'REQUEST_METHOD': 'GET'})
+        resp = self.controller.GET(req)
+        self.assertEquals(resp.status_int, 200)
+        self.assertEquals(resp.content_type, 'text/plain')
+        self.assertEquals(resp.body, plain_body)
+
     def test_GET_json_last_modified(self):
         # make a container
         req = Request.blank('/sda1/p/a/jsonc', environ={'REQUEST_METHOD': 'PUT',
@@ -961,10 +969,6 @@ class TestContainerController(unittest.TestCase):
                                 environ={'REQUEST_METHOD': 'GET'})
             resp = self.controller.GET(req)
             self.assertEquals(resp.status_int, 200)
-        req = Request.blank('/sda1/p/a/c?format=Foo!',
-                            environ={'REQUEST_METHOD': 'GET'})
-        resp = self.controller.GET(req)
-        self.assertEquals(resp.status_int, 400)
 
     def test_params_utf8(self):
         self.controller.PUT(Request.blank('/sda1/p/a/c',
